==> CGI-Bus-0.55.tar.gz: CGI-Bus-0.55/lib/CGI/Bus/lngbase/CGI_Bus_tmsql_ru.pm <==
#!perl -w
#
# admiral 
# 16/12/2001
#
# 

package CGI::Bus::lngbase::CGI_Bus_tmsql_ru; # Language base
#use CGI::Bus::lngbase::CGI_Bus_tm_ru;
use CGI::Bus::lngbase::CGI_Bus_tmsql;
use strict;

1;

sub lngbase {
 my @msg;
 push @msg, CGI::Bus::lngbase::CGI_Bus_tmsql::lngbase;
#push @msg, CGI::Bus::lngbase::CGI_Bus_tm_ru::lngbase;
 push @msg,
 (-lgn=>['',    '  ']
 ,-nap=>['',     ' ']
 ,-nup=>['',     ' ']
 ,-nth=>['',    '  -']
 ,-bck=>['',    '   ']
 ,-lst=>['',     '     ()']
 ,-lsr=>['',     '  ']
 ,-qry=>['',  '  () ']
 ,-crt=>['',  '  ,   \'\'    ']
 ,-sel=>['',  '()    ,  ']
 ,-edt=>['',   '  /  ']
 ,-frm=>['',     '   ,  ']
 ,-upd=>['','     ,    ']
 ,-del=>['',  '     ']
 ,-ins=>['', '     ']
 ,-hlp=>['',  '  ']

 ,'op!let' =>['',       ' \'$_\' ']
 ,'op!acl2'=>['',       ' \'$_\'    ']
 ,'!constr'=>['',       ' ']
 ,'fldReq' =>['',       '  \'$_\' ']
 ,'!rfetch'=>['',       '     ']
 ,'rfetch' =>['',       '$_  ']
 ,'rfetchf'=>['',       ' $_  ']
 ,'Success'=>['',  ' ']
 ,'Failure'=>['',' ']

 ,'Versions'  =>['',   ' ']
 ,'LIST'      =>['',  ' ']
#,'WHERE'     =>['WHERE',    'WHERE SQL query condition']
 ,'F-TEXT'    =>['',    ' ']
#,'ORDER BY'  =>['ORDER BY', 'ORDER BY SQL query condition clause']
 ,'LIMIT ROWS'=>['',   '   ']

 ,'Help'           =>['',         '']
 ,'Lists'          =>[' ()',',    ,   ']
 ,'Fields'         =>['',            ' ,   ']
 ,'Commands'       =>['',         ',   ']
 ,'Versioning'     =>['', '    ']
 ,'-vsd-svd'       =>['',                '  ,        ']
 ,'-vsd-sd'        =>['',                '   ']
 ,'File Store'     =>[' ','    ']
 ,'-fsd-url'       =>['',                '   ']
 ,'-fsd-vsurl'     =>['',                '    ']
 ,'-fsd-vsd-e'     =>[' ','             $_']
 ,'-fsd-vsd-ei'    =>[' ','  \'\' $_ -> \'\'         ']
 );
 @msg
}

==> CGI-Bus-0.56.tar.gz: CGI-Bus-0.56/lib/CGI/Bus/lngbase/CGI_Bus_tmsql_ru.pm <==
#!perl -w
#
# admiral 
# 16/12/2001
#
# 

package CGI::Bus::lngbase::CGI_Bus_tmsql_ru; # Language base
#use CGI::Bus::lngbase::CGI_Bus_tm_ru;
use CGI::Bus::lngbase::CGI_Bus_tmsql;
use strict;

1;

sub lngbase {
 my @msg;
 push @msg, CGI::Bus::lngbase::CGI_Bus_tmsql::lngbase;
#push @msg, CGI::Bus::lngbase::CGI_Bus_tm_ru::lngbase;
 push @msg,
 (-nap=>['',     ' ']
 ,-nup=>['',     ' ']
 ,-nth=>['',    '  -']
 ,-bck=>['',    '   ']
 ,-lgn=>['',    '  ']
 ,-lst=>['',     '     ()']
 ,-lsr=>['',     '  ']
 ,-qry=>['',   '  () ']
 ,-crt=>['',  '  ,   \'\'    ']
 ,-sel=>['',  '()    ,  ']
 ,-edt=>['',   '  /  ']
 ,-frm=>['',     '   ,  ']
 ,-upd=>['','     ,    ']
 ,-del=>['',  '     ']
 ,-ins=>['', '     ']
 ,-hlp=>['',  '  ']

 ,'op!let' =>['',       ' \'$_\' ']
 ,'op!acl2'=>['',       ' \'$_\'    ']
 ,'!constr'=>['',       ' ']
 ,'fldReq' =>['',       '  \'$_\' ']
 ,'!rfetch'=>['',       '     ']
 ,'rfetch' =>['',       '$_  ']
 ,'rfetchf'=>['',       ' $_  ']
 ,'Success'=>['',  ' ']
 ,'Failure'=>['',' ']

 ,'Versions'  =>['',   ' ']
 ,'LIST'      =>['',  ' ']
#,'WHERE'     =>['WHERE',    'WHERE SQL query condition']
 ,'F-TEXT'    =>['',    ' ']
#,'ORDER BY'  =>['ORDER BY', 'ORDER BY SQL query condition clause']
 ,'LIMIT ROWS'=>['',   '   ']

 ,'Help'           =>['',         '']
 ,'Lists'          =>[' ()',',    ,   ']
 ,'Fields'         =>['',            ' ,   ']
 ,'Commands'       =>['',         ',   ']
 ,'Versioning'     =>['', '    ']
 ,'-vsd-svd'       =>['',                '  ,        ']
 ,'-vsd-sd'        =>['',                '   ']
 ,'File Store'     =>[' ','    ']
 ,'-fsd-url'       =>['',                '   ']
 ,'-fsd-vsurl'     =>['',                '    ']
 ,'-fsd-vsd-e'     =>[' ','             $_']
 ,'-fsd-vsd-ei'    =>[' ','  \'\' $_ -> \'\'         ']
 );
 @msg
}
